@@ -1,14 +1,31 @@
+# Copyright (C) 2014 - 2015  Jack O. Wasey
+#
+# This file is part of icd9.
+#
+# icd9 is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# icd9 is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with icd9. If not, see <http:#www.gnu.org/licenses/>.
+
 #' @title extract assignments from a SAS FORMAT definition.
 #' @description this is modelled entirely on a single chunk of SAS code, but
 #'   hopefully will have some generalizability. It relies heavily on lists and
 #'   regex, but, as you will see from the code, R is not a great language with
 #'   which to write a SAS parser.
-#'
-#'   #example
-#'   #sasFormatExtract(readLines('inst/extdata//comformat2012-2013.txt'))
-#'
 #' @param sasTxt is a character vector, with one item per line, e.g. from
 #'   \code{readLines}
+#' @examples
+#'   \dontrun{
+#'   sasFormatExtract(readLines('inst/extdata//comformat2012-2013.txt'))
+#'   }
 #' @references
 #' \url{http://support.sas.com/documentation/cdl/en/proc/61895/HTML/default/viewer.htm#a002473474.htm}
 #' \url{https://communities.sas.com/thread/47571?start=0&tstart=0}
@@ -19,15 +36,13 @@ sasFormatExtract <- function(sasTxt) {
 
   # collapse everything onto one big line, so we can filter multi-line
   # commments. No ability to do multiline regex along a vector.
-  sasTxt <- paste(sasTxt, collapse=" \\n")
+  sasTxt <- paste(sasTxt, collapse = " \\n")
 
   # sas comments are in the form /* ... */ inline/multiline, or * ... ;
   sasTxt <- gsub(pattern = "/\\*.*?\\*/", replacement = "", x = sasTxt) # nolint
   sasTxt <- gsub(pattern = "\\n\\*.*?;", replacement = "\\n", x = sasTxt) # nolint
 
-  sasTxt <- strsplit(sasTxt, split="\\;")[[1]]
-  #sasCleanLines <- strsplit(sasNoComments, split="\\\\n")[[1]]
-  #sasNonEmptyLines <- sasCleanLines[sasCleanLines!=""]
+  sasTxt <- strsplit(sasTxt, split = "\\;")[[1]]
 
   #strip whitespace and ?undetected newline characters, replace with single
   #spaces.
@@ -41,7 +56,7 @@ sasFormatExtract <- function(sasTxt) {
   # put each VALUE declaration in a vector element
   allAssignments <- strMultiMatch(
     pattern = "^VALUE[[:space:]]+([[:graph:]]+)[[:space:]]+(.+)[[:space:]]*$",
-    text=sasTxt)
+    text = sasTxt)
 
   out <- list()
 
@@ -65,12 +80,14 @@ sasFormatExtract <- function(sasTxt) {
 #' @keywords internal programming list
 sasParseAssignments <- function(x, stripWhiteSpace = TRUE, stripQuotes = TRUE) {
 
-  stopifnot(length(x) == 1) # sorry...
+  assertString(x)
+  assertFlag(stripWhiteSpace)
+  assertFlag(stripQuotes)
   # splitting with clever regex to separate each pair of assignments seems
   # tricky, so doing it in steps.
   # n.b. this is a list with list per input row.
   halfway <- as.list(unlist(
-    strsplit(x, split="[[:space:]]*=[[:space:]]*")
+    strsplit(x, split = "[[:space:]]*=[[:space:]]*")
   ))
 
   # we need to match the first unquoted space to get the boundary between the
@@ -106,11 +123,10 @@ sasParseAssignments <- function(x, stripWhiteSpace = TRUE, stripQuotes = TRUE) {
 
 
   out <- list()
-  for (pair in seq(from=1, to=length(threequarters), by=2)) {
-    #flog.debug("%s = %s", threequarters[pair], threequarters[pair+1])
+  for (pair in seq(from = 1, to = length(threequarters), by = 2)) {
     if (stripWhiteSpace) {
-      outwhite <- gsub(pattern="[[:space:]]*",
-                       replacement="",
+      outwhite <- gsub(pattern = "[[:space:]]*",
+                       replacement = "",
                        threequarters[pair])
     } else {
       outwhite <- threequarters[pair]
@@ -129,8 +145,8 @@ sasParseAssignments <- function(x, stripWhiteSpace = TRUE, stripQuotes = TRUE) {
 #'   string itself)
 #' @keywords internal manip util
 sasDropOtherAssignment <- function(x) {
-  # asssuming one "="
-  lapply(x, function(y) strsplit(y, split="[[:space:]]*=")[[1]][1])
+  stopifnot(sapply(regmatches(x, gregexpr("=", x)), length) == 1)
+  lapply(x, function(y) strsplit(y, split = "[[:space:]]*=")[[1]][1])
 }
 
 #' @title extract quoted or unquoted SAS string definitions
@@ -142,15 +158,13 @@ sasDropOtherAssignment <- function(x) {
 #'   like \code{readLines(someSasFilePath)}
 #' @keywords internal programming list
 sasExtractLetStrings <- function(x) {
-
-  #letStr <- grep(pattern="LET.*STR", x)
   a <- strMultiMatch(
     "%LET ([[:alnum:]]+)[[:space:]]*=[[:space:]]*%STR\\(([[:print:]]+?)\\)",
     text = x, dropEmpty = TRUE)
-  vls <- vapply(a, FUN=function(x) x[[2]], FUN.VALUE = "")
-  splt <- strsplit(vls, split=",")
+  vls <- vapply(a, FUN = function(x) x[[2]], FUN.VALUE = "")
+  splt <- strsplit(vls, split = ",")
   result <- lapply(splt, strip, pattern = "'") # strip single quotes
   result <- lapply(result, strip, pattern = '"') # strip double quotes
-  names(result) <- vapply(a, FUN = function(x) x[[1]], FUN.VALUE="")
+  names(result) <- vapply(a, FUN = function(x) x[[1]], FUN.VALUE = "")
   result
 }
