@@ -16,16 +16,23 @@
 // along with icd9. If not, see <http://www.gnu.org/licenses/>.
 
 // [[Rcpp::interfaces(r, cpp)]]
-#include <local.h>
+#include "local.h"
+#include <Rcpp.h>
+#ifdef ICD9_STD_PARALLEL
+#include <parallel/algorithm>
+#else
 #include <algorithm>
+#endif
 
-using namespace Rcpp;
-
-void buildMap(const List& icd9Mapping, VecVecInt& map) {
-  for (List::const_iterator mi = icd9Mapping.begin(); mi != icd9Mapping.end();
+void buildMap(const Rcpp::List& icd9Mapping, VecVecInt& map) {
+  for (Rcpp::List::const_iterator mi = icd9Mapping.begin(); mi != icd9Mapping.end();
   ++mi) {
-    VecInt vec(as<VecInt>(*mi));
+    VecInt vec(Rcpp::as<VecInt>(*mi));
     std::sort(vec.begin(), vec.end());
+    // to force a call to parallel version, not sure whether this forces
+    // parallel execution or just starts the heuristics which may invoke
+    // parallel execution:
+    //__gnu_parallel::sort(vec.begin(), vec.end());
 #ifdef ICD9_DEBUG_SETUP_TRACE
     Rcpp::Rcout << "pushing back vec of length: " << vec.size() << "\n";
 #endif
@@ -56,17 +63,22 @@ void buildVisitCodesVec(const SEXP& icd9df,
 
 #ifdef ICD9_DEBUG
 #ifdef HAVE_CXX11
-  Rcout << "unordered_map is available (or at least C++11 is in some form)\n";
+  Rcpp::Rcout << "unordered_map is available (or at least C++11 is in some form)\n";
 #else
-  Rcout << "unordered_map is not available\n";
+  Rcpp::Rcout << "unordered_map is not available\n";
 #endif
 #endif
   VisLk vis_lookup;
 
+#ifdef ICD9_DEBUG
+  Rcpp::Rcout << "vcdb resized to length vlen = " << vlen << "\n";
+#endif
   vcdb.resize(vlen); // over-estimate and allocate all at once (alternative is to reserve)
   VecVecIntSz vcdb_max_idx = -1; // we increment immediately to zero as first index
   VecVecIntSz vcdb_new_idx;
-  VecVecIntSz vcdb_last_idx = 2094967295; // random number less than 2^31 (to avoid 32bit R build warning) just to initialize: should always been initialized, though.
+  // 2094967295 is a random number less than 2^31 (to avoid 32bit R build
+  // warning) just to initialize: should always been initialized, though.
+  VecVecIntSz vcdb_last_idx = 2094967295;
   if (TYPEOF(vsexp) != STRSXP) {
     Rcpp::stop("buildVisitCodesVec requires STRSXP");
   }
@@ -91,7 +103,7 @@ void buildVisitCodesVec(const SEXP& icd9df,
         if (found != vis_lookup.end()) {
           vcdb[found->second].push_back(n);
 #ifdef ICD9_DEBUG_SETUP_TRACE
-          Rcpp::Rcout << "repeat key " << vi << " found at position " << vcdb_use_idx << "\n";
+          Rcpp::Rcout << "repeat key " << vi << " found at position " << vcdb_new_idx << "\n";
 #endif
           continue;
         } else {
