@@ -18,21 +18,26 @@
 #ifndef CONVERT_H_
 #define CONVERT_H_
 
-#ifndef Rcpp_hpp
+#include "local.h"
+#include "util.h"
+#include "is.h"
+#include "manip.h"
 #include <Rcpp.h>
-#endif
-Rcpp::List icd9ShortToParts(const Rcpp::CharacterVector icd9Short,
-		const Rcpp::String minorEmpty = "");
-Rcpp::List icd9DecimalToParts(const Rcpp::CharacterVector icd9Decimal,
-		const Rcpp::String minorEmpty = "");
+
+// need default argument here for other functions to exploit,
+// but this is then not exported by Rcpp (which works on the function body).
+Rcpp::List icd9ShortToPartsCpp(const Rcpp::CharacterVector icd9Short, const Rcpp::String minorEmpty = "");
+
+Rcpp::List icd9DecimalToPartsCpp(const Rcpp::CharacterVector icd9Decimal, const Rcpp::String minorEmpty = "");
 Rcpp::CharacterVector icd9PartsToShort(const Rcpp::List parts);
 Rcpp::CharacterVector icd9PartsToDecimal(const Rcpp::List parts);
 Rcpp::CharacterVector icd9MajMinToShort(const Rcpp::CharacterVector major,
-		const Rcpp::CharacterVector mnr);
+		const Rcpp::CharacterVector minor);
 Rcpp::CharacterVector icd9MajMinToDecimal(const Rcpp::CharacterVector major,
-		const Rcpp::CharacterVector mnr);
+		const Rcpp::CharacterVector minor);
 Rcpp::CharacterVector icd9DecimalToShort(
 		const Rcpp::CharacterVector icd9Decimal);
 Rcpp::CharacterVector icd9ShortToDecimal(const Rcpp::CharacterVector icd9Short);
+Rcpp::CharacterVector icd9GetMajor(const Rcpp::CharacterVector icd9, const bool isShort);
 
 #endif /* CONVERT_H_ */
