@@ -18,9 +18,7 @@
 #ifndef RANGES_H_
 #define RANGES_H_
 
-#ifndef Rcpp_hpp
 #include <Rcpp.h>
-#endif
 
 Rcpp::CharacterVector icd9ChildrenShortCpp(Rcpp::CharacterVector icd9Short, bool onlyReal = true);
 Rcpp::CharacterVector icd9ChildrenDecimalCpp(Rcpp::CharacterVector icd9Decimal, bool onlyReal = true);
